@@ -2,6 +2,6 @@ library(ggplot)
 source.with.err <- function(path) {
 	tryCatch(source(path), error = function(x) print(path))
 }
-lapply(dir("~/documents/ggplot/ggplot/R", full.name=T), source.with.err)
+lapply(dir("~/Documents/ggplot/releases/ggplot-0.4.1/R/", full.name=T), source.with.err)
 
 
